Registro | OiRA

Temas

# Registro

## ¿Por qué tengo que registrarme?

Lo primero que se le pedirá cuando empiece su primera evaluación de riesgos es que cree una cuenta OiRA; se trata de un proceso sencillo y rápido.

Registrarse le permitirá iniciar sesión en cualquier momento para acceder a sus datos, continuar con evaluaciones anteriores o iniciar evaluaciones nuevas.

Mediante su registro, el sistema OiRA guarda todas sus sesiones y siempre tendrá sus datos disponibles.

Acceda aquí para obtener información adicional sobre cómo tratamos sus datos personales.

## ¿Cuál es la diferencia entre un usuario registrado y una sesión de prueba?

Una sesión de prueba está pensada para que las personas interesadas examinen la herramienta antes de registrarse. Sin embargo, durante una sesión de prueba, sus datos no se guardan y más adelante no podrá recuperar ninguna información introducida. Además, una sesión de prueba no le permite imprimir ninguno de los informes, mientras que, si se registra, podrá documentar su evaluación de riesgos.

## Registrar una cuenta nueva

¿Es su primera visita? Para empezar, siga estos sencillos pasos:

1) Haga clic en «Registrarse» para ver el formulario de registro.

Formulario de registro

2) Introduzca su dirección de correo electrónico y elija una contraseña (debe introducirla dos veces).

3) Haga clic en «Siguiente» para registrar su cuenta.

4) Lea y acepte la política de privacidad para continuar.

Se iniciará sesión directamente en el sistema OiRA.

## Iniciar sesión en una cuenta existente

Si ya se ha registrado, puede acceder a su cuenta de esta forma.

1) Entre en el formulario de inicio de sesión. Se le mostrará un enlace al formulario de inicio de sesión cada vez que intente acceder a OiRA, hasta que haya iniciado la sesión.

Formulario de inicio de sesión

2) Introduzca su dirección de correo electrónico y su contraseña.

3) Inicie sesión haciendo clic en el botón «Iniciar sesión».

Una vez haya iniciado la sesión, verá la pantalla que se muestra a continuación. Desde aquí puede iniciar una nueva evaluación de riesgos o acceder a evaluaciones de riesgos ya iniciadas.

Tablero de control

Inicie una nueva evaluación de riesgos asignándole un título (por ejemplo, Miempresa 2020-07-03) o acceda a una de sus evaluaciones de riesgos anteriores. Todas sus evaluaciones de riesgos se guardan, a no ser que las elimine.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More